#!/usr/bin/env python3
"""
TCP SYN Checker
Parameters:
    - IP: Target IP address
    - port: Target port number
Requires root/admin privileges
"""
from scapy.all import *
import argparse
import sys

def syn_check(ip, port):
    try:
        # Create SYN packet
        syn_packet = IP(dst=ip)/TCP(dport=port, flags="S")
        
        # Send packet and wait for response
        response = sr1(syn_packet, timeout=2, verbose=0)
        
        if response is None:
            print(f"No response from {ip}:{port}")
        elif response.haslayer(TCP):
            if response[TCP].flags == 0x12:  # SYN-ACK
                print(f"Port {port} is open on {ip}")
            elif response[TCP].flags == 0x14:  # RST-ACK
                print(f"Port {port} is closed on {ip}")
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="TCP SYN Checker")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("port", type=int, help="Target port number")
    args = parser.parse_args()
    
    syn_check(args.ip, args.port)
